import MainSmLayout from "@/Layouts/MainSmLayout";
import Data from "@/DataJson/Data";
import PagTitle from "@/Components/Title/PagTitle";
import InputLabel from "@/Components/FormComponents/InputLabel";
import Input from "@/Components/FormComponents/Input";
import TextArea from "@/Components/FormComponents/TextArea";
import InputCurrencyMask from "@/Components/FormComponents/InputCurrencyMask";
import Button from "@/Components/Buttons/Button";
import { Link, useForm } from "@inertiajs/react";
import toast, { Toaster } from 'react-hot-toast';

export default function Create() {

    const { data, setData, post, processing } = useForm({
        title: '',
        description: '',
        price: '',
    });

    const onSubmit = (e) => {
        e.preventDefault();

        post(route('course.store'), {
            onError: (errors) => {
                if (errors) {
                    toast.error(errors.error, {
                        autoClose: 5000,
                    });
                }
            }
        });
    };

    return (
        <MainSmLayout navigation={Data.RESET_PAY.NAVIGATION} homeLink={route('resetpay')} icon={Data.RESET_PAY.ICON}>
            <Toaster />

            <div className="mb-3 pb-3 border-b border-border">
                <PagTitle title="Meus Cursos" subtitle="Crie um novo curso ou turma para começar a vender." />
            </div>

            <div className="mx-auto max-w-3xl mt-10">

                <Link href={route('course')}>
                    <p className="text-text-primary text-[.8rem] hover:text-text-white mb-3">
                        <i className="bi bi-arrow-left"></i> Voltar para meus cursos
                    </p>
                </Link>

                <form onSubmit={onSubmit} className="rounded-2xl bg-background-secondary border border-border  px-3 py-6">
                    <div className="grid grid-cols-2 lg:grid-cols-4 gap-4">

                        <div className="col-span-2 lg:col-span-3">
                            <InputLabel htmlFor="title" value="Nome do Curso" required />
                            <Input
                                id="title"
                                name="title"
                                className="block w-full"
                                isFocused={true}
                                required
                                placeholder="Nome do curso"
                                value={data.title}
                                onChange={(e) => setData("title", e.target.value)}
                            />
                        </div>

                        <div className="col-span-2 lg:col-span-1">
                            <InputLabel htmlFor="price" value="Preço do Curso" required />
                            <InputCurrencyMask
                                id="price"
                                name="price"
                                className="block w-full"
                                placeholder="R$ 0,00"
                                required
                                value={data.price}
                                onChangeValue={(e) => setData("price", e.target.value)}
                            />
                        </div>

                        <div className="col-span-2 lg:col-span-4">
                            <InputLabel htmlFor="description" value="Descrição curta do curso" />
                            <TextArea
                                id="description"
                                name='description'
                                placeholder="Descrição curta do curso"
                                className="block w-full"
                                value={data.description}
                                onChange={(e) => setData("description", e.target.value)}
                            />
                        </div>
                    </div>

                    <div className="flex justify-center items-center mt-6">
                        <Button disabled={processing}>Criar Curso</Button>
                    </div>
                </form>
            </div>
        </MainSmLayout>
    );
}